@@ -61,6 +61,7 @@ from .tools.export_tool import ExportTool
 from .tools.position_tool import PositionTool
 from .tools.material_tool import MaterialTool
 from .tools.import_excel_tool import ImportExcelTool
+from .tools.upload_file_tool import UploadFileTool
 from .tools.create_harris_matrix_tool import CreateHarrisMatrixTool
 from .tools.configure_em_nodes_tool import ConfigureEMNodesTool
 from .tools.create_database_tool import CreateDatabaseTool
@@ -68,6 +69,16 @@ from .tools.pyarchinit_sync_tool import PyArchInitSyncTool
 from .tools.chatgpt_search_tool import ChatGPTSearchTool
 from .tools.chatgpt_fetch_tool import ChatGPTFetchTool
 from .tools.database_manager_tool import DatabaseManagerTool
+from .tools.data_management_tool import DataManagementTool
+from .tools.service_management_tool import ServiceManagementTool
+from .tools.export_harris_matrix_graphml_tool import ExportHarrisMatrixGraphMLTool
+from .tools.validate_stratigraphic_relationships_tool import ValidateStratigraphicRelationshipsTool
+from .tools.validate_relationship_format_tool import ValidateRelationshipFormatTool
+from .tools.generate_report_tool import GenerateReportTool
+from .tools.validate_relationship_integrity_tool import ValidateRelationshipIntegrityTool
+from .tools.media_management_tool import MediaManagementTool
+from .tools.thesaurus_management_tool import ThesaurusManagementTool
+from .tools.data_import_parser_tool import DataImportParserTool
 
 from .prompts.stratigraphic_model_prompt import StratigraphicModelPrompt
 from .prompts.period_visualization_prompt import PeriodVisualizationPrompt
@@ -83,8 +94,11 @@ class PyArchInitMCPServer:
 
     Exposes:
     - 5 Resources (GraphML, US, Periods, Relationships, Sites)
-    - 13 Tools (build_3d, filter, export, position, material, import_excel, create_harris_matrix,
-                configure_em_nodes, create_database, pyarchinit_sync, search, fetch, manage_database_connections)
+    - 23 Tools (build_3d, filter, export, position, material, import_excel, create_harris_matrix,
+                configure_em_nodes, create_database, pyarchinit_sync, search, fetch,
+                manage_database_connections, manage_data, manage_services, export_harris_matrix_graphml,
+                validate_stratigraphic_relationships, validate_relationship_format, generate_report,
+                validate_relationship_integrity, manage_media, manage_thesaurus, import_data)
     - 3 Prompts (stratigraphic_model, period_visualization, us_description)
 
     Architecture:
@@ -211,6 +225,12 @@ class PyArchInitMCPServer:
             config=self.config,
         )
 
+        # Upload File Tool
+        self.tools["upload_file"] = UploadFileTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
         # Create Harris Matrix Tool
         self.tools["create_harris_matrix"] = CreateHarrisMatrixTool(
             db_session=self.db_session,
@@ -253,6 +273,66 @@ class PyArchInitMCPServer:
             config=self.config,
         )
 
+        # Data Management Tool (CRUD + Validation)
+        self.tools["manage_data"] = DataManagementTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Service Management Tool (Start/Stop services)
+        self.tools["manage_services"] = ServiceManagementTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Export Harris Matrix GraphML Tool (Auto-export from database)
+        self.tools["export_harris_matrix_graphml"] = ExportHarrisMatrixGraphMLTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Validate Stratigraphic Relationships Tool (Data integrity)
+        self.tools["validate_stratigraphic_relationships"] = ValidateStratigraphicRelationshipsTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Validate Relationship Format Tool (Symbols vs Textual)
+        self.tools["validate_relationship_format"] = ValidateRelationshipFormatTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Generate Report Tool (Comprehensive reports and summaries)
+        self.tools["generate_report"] = GenerateReportTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Validate Relationship Integrity Tool (Bidirectional integrity checks)
+        self.tools["validate_relationship_integrity"] = ValidateRelationshipIntegrityTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Media Management Tool (Upload and manage media files)
+        self.tools["manage_media"] = MediaManagementTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Thesaurus Management Tool (Controlled vocabularies)
+        self.tools["manage_thesaurus"] = ThesaurusManagementTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
+        # Data Import Parser Tool (Automatic data import from CSV, Excel, JSON, XML)
+        self.tools["import_data"] = DataImportParserTool(
+            db_session=self.db_session,
+            config=self.config,
+        )
+
         logger.info(f"Registered {len(self.tools)} tools")
 
     def _register_prompts(self):
@@ -326,6 +406,7 @@ class PyArchInitMCPServer:
             @self.server.list_tools()
             async def handle_list_tools():
                 """List available tools"""
+                logger.info(f"🔍 MCP: list_tools() called - returning {len(self.tools)} tools")
                 tools = []
                 for tool in self.tools.values():
                     desc = tool.to_tool_description()
@@ -336,15 +417,21 @@ class PyArchInitMCPServer:
                             inputSchema=desc.input_schema,
                         )
                     )
+                    logger.debug(f"  - Tool: {desc.name}")
+                logger.info(f"✓ MCP: Tools returned: {[t.name for t in tools]}")
                 return tools
 
             @self.server.call_tool()
             async def handle_call_tool(name: str, arguments: Dict[str, Any]):
                 """Call a tool"""
+                logger.info(f"🔧 MCP: call_tool() called - tool={name}, args={list(arguments.keys())}")
                 if name not in self.tools:
+                    logger.error(f"✗ MCP: Unknown tool: {name}")
                     raise ValueError(f"Unknown tool: {name}")
 
-                return await self.tools[name].execute(arguments)
+                result = await self.tools[name].execute(arguments)
+                logger.info(f"✓ MCP: Tool {name} executed successfully")
+                return result
 
             @self.server.list_prompts()
             async def handle_list_prompts():
