@@ -25,12 +25,18 @@ from typing import Dict, List, Tuple, Optional, Set
 from pathlib import Path
 import re
 import os
+import sys
+import logging
+import warnings
 from datetime import datetime
+from io import StringIO
 
 from pyarchinit_mini.models.us import US
 from pyarchinit_mini.models.site import Site
 from pyarchinit_mini.database.connection import DatabaseConnection
 
+logger = logging.getLogger(__name__)
+
 
 def safe_int(value) -> Optional[int]:
     """
@@ -215,9 +221,28 @@ class ExtendedMatrixExcelParser:
             DataFrame with Excel data
         """
         try:
-            self.df = pd.read_excel(self.excel_path)
-            self.statistics['total_rows'] = len(self.df)
+            # Suppress all warnings during Excel loading
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+
+                # Also redirect stderr at file descriptor level for C library warnings
+                import tempfile
+                null_fd = os.open(os.devnull, os.O_RDWR)
+                old_stderr_fd = os.dup(2)
+                os.dup2(null_fd, 2)
+
+                try:
+                    self.df = pd.read_excel(self.excel_path)
+                    self.statistics['total_rows'] = len(self.df)
+                finally:
+                    # Restore stderr
+                    os.dup2(old_stderr_fd, 2)
+                    os.close(old_stderr_fd)
+                    os.close(null_fd)
+
+            logger.info(f"✓ Loaded {len(self.df)} rows from {self.excel_path.name}")
             print(f"✓ Loaded {len(self.df)} rows from {self.excel_path.name}")
+            sys.stdout.flush()
             return self.df
         except Exception as e:
             error_msg = f"Error loading Excel: {e}"
@@ -269,7 +294,12 @@ class ExtendedMatrixExcelParser:
 
     def import_us_records(self):
         """Import US records from Excel to database."""
+        logger.info(f"📦 Importing US records...")
         print(f"\n📦 Importing US records...")
+        sys.stdout.flush()
+
+        us_counter = 0
+        progress_interval = 10
 
         for idx, row in self.df.iterrows():
             try:
@@ -282,6 +312,7 @@ class ExtendedMatrixExcelParser:
 
                     # Process each US ID
                     for us_id in us_ids:
+                        us_counter += 1
                         us_number = self.extract_us_number(us_id)
                         unit_type = self.determine_unit_type(us_id)
 
@@ -337,7 +368,12 @@ class ExtendedMatrixExcelParser:
                                 existing_us.larghezza_media = safe_float(row.get('larghezza_media'))
 
                             self.statistics['us_updated'] += 1
-                            print(f"  ↻ Updated {unit_type} {us_number}")
+                            # Progress logging every 10 US
+                            if us_counter % progress_interval == 0:
+                                progress_msg = f"⏳ Progress: {us_counter}/{self.statistics['total_rows']} US processed..."
+                                logger.info(progress_msg)
+                                print(progress_msg)
+                                sys.stdout.flush()
                         else:
                             # Create new US (id_us will be auto-generated)
                             new_us = US(
@@ -368,7 +404,12 @@ class ExtendedMatrixExcelParser:
                             )
                             session.add(new_us)
                             self.statistics['us_created'] += 1
-                            print(f"  + Created {unit_type} {us_number}")
+                            # Progress logging every 10 US
+                            if us_counter % progress_interval == 0:
+                                progress_msg = f"⏳ Progress: {us_counter}/{self.statistics['total_rows']} US processed..."
+                                logger.info(progress_msg)
+                                print(progress_msg)
+                                sys.stdout.flush()
 
                         # Create or update periodizzazione record if period/fase specified
                         if period or fase:
@@ -414,10 +455,15 @@ class ExtendedMatrixExcelParser:
 
     def import_relationships(self):
         """Import stratigraphic relationships from Excel."""
+        logger.info(f"🔗 Importing relationships...")
         print(f"\n🔗 Importing relationships...")
+        sys.stdout.flush()
 
         from pyarchinit_mini.models.harris_matrix import USRelationships
 
+        rel_counter = 0
+        progress_interval = 50  # More frequent for relationships since there are more
+
         for idx, row in self.df.iterrows():
             try:
                 with self.db_connection.get_session() as session:
@@ -453,7 +499,14 @@ class ExtendedMatrixExcelParser:
                                     )
                                     session.add(new_rel)
                                     self.statistics['relationships_created'] += 1
-                                    print(f"  + Created: {source_us_number} {pyarch_rel} {target_us_number}")
+                                    rel_counter += 1
+
+                                    # Progress logging every N relationships
+                                    if rel_counter % progress_interval == 0:
+                                        progress_msg = f"⏳ Relationship progress: {rel_counter} relationships created..."
+                                        logger.info(progress_msg)
+                                        print(progress_msg)
+                                        sys.stdout.flush()
 
                     # Commit is done automatically by context manager
 
@@ -516,12 +569,13 @@ class ExtendedMatrixExcelParser:
             self.statistics['errors'].append(error_msg)
             print(f"✗ {error_msg}")
 
-    def generate_graphml(self, output_path: Optional[str] = None) -> str:
+    def generate_graphml(self, output_path: Optional[str] = None, reverse_edges: bool = False) -> str:
         """
         Generate GraphML file for Extended Matrix visualization.
 
         Args:
             output_path: Optional output path for GraphML file
+            reverse_edges: Reverse edge direction in GraphML (default: False)
 
         Returns:
             Path to generated GraphML file
@@ -561,7 +615,8 @@ class ExtendedMatrixExcelParser:
                 output_path=output_path,
                 use_extended_labels=True,
                 site_name=self.site_name,
-                include_periods=True
+                include_periods=True,
+                reverse_epochs=reverse_edges
             )
 
             if result_path:
@@ -579,12 +634,14 @@ class ExtendedMatrixExcelParser:
             print(f"✗ {error_msg}")
             raise
 
-    def run(self, generate_graphml: bool = True) -> Dict:
+    def run(self, generate_graphml: bool = True, output_dir: Optional[str] = None, reverse_edges: bool = False) -> Dict:
         """
         Run complete import process.
 
         Args:
             generate_graphml: Whether to generate GraphML file (default: True)
+            output_dir: Output directory for GraphML file (optional)
+            reverse_edges: Reverse edge direction in GraphML (default: False)
 
         Returns:
             Dictionary with import statistics
@@ -618,7 +675,14 @@ class ExtendedMatrixExcelParser:
             # Step 6: Generate GraphML (optional)
             graphml_path = None
             if generate_graphml:
-                graphml_path = self.generate_graphml()
+                # Build output path
+                if output_dir:
+                    os.makedirs(output_dir, exist_ok=True)
+                    output_path = os.path.join(output_dir, f"{self.site_name.replace(' ', '_')}_extended_matrix.graphml")
+                else:
+                    output_path = None
+
+                graphml_path = self.generate_graphml(output_path=output_path, reverse_edges=reverse_edges)
                 self.statistics['graphml_path'] = graphml_path
 
             # Print summary
@@ -651,8 +715,11 @@ class ExtendedMatrixExcelParser:
 def import_extended_matrix_excel(
     excel_path: str,
     site_name: str,
+    db_url: str = None,
     generate_graphml: bool = True,
-    db_connection: Optional[DatabaseConnection] = None
+    db_connection: Optional[DatabaseConnection] = None,
+    output_dir: Optional[str] = None,
+    reverse_edges: bool = False
 ) -> Dict:
     """
     Convenience function to import Extended Matrix Excel file.
@@ -660,8 +727,11 @@ def import_extended_matrix_excel(
     Args:
         excel_path: Path to Excel file
         site_name: Archaeological site name
+        db_url: Database URL string (optional, for backwards compatibility)
         generate_graphml: Whether to generate GraphML (default: True)
         db_connection: Database connection (optional)
+        output_dir: Output directory for GraphML file (optional)
+        reverse_edges: Reverse edge direction in GraphML (default: False)
 
     Returns:
         Dictionary with import statistics
@@ -670,13 +740,22 @@ def import_extended_matrix_excel(
         >>> stats = import_extended_matrix_excel(
         ...     excel_path='data/MetroC_AmbaAradam.xlsx',
         ...     site_name='Metro C - Amba Aradam',
-        ...     generate_graphml=True
+        ...     generate_graphml=True,
+        ...     reverse_edges=False
         ... )
         >>> print(f"Imported {stats['us_created']} US records")
     """
+    # Handle db_url for backwards compatibility
+    if db_url and not db_connection:
+        db_connection = DatabaseConnection.from_url(db_url)
+
     parser = ExtendedMatrixExcelParser(
         excel_path=excel_path,
         site_name=site_name,
         db_connection=db_connection
     )
-    return parser.run(generate_graphml=generate_graphml)
+    return parser.run(
+        generate_graphml=generate_graphml,
+        output_dir=output_dir,
+        reverse_edges=reverse_edges
+    )
